@@ -6,7 +6,7 @@ import os, sys, ast, json, glob, platform, subprocess, random, requests, socket
 
 # inc imports.
 import syst3m, cl1
-from fil3s import Files, Formats
+from fil3s import *
 from r3sponse import r3sponse
 
 # source.
@@ -15,6 +15,9 @@ SOURCE_PATH = syst3m.defaults.source_path(__file__, back=3)
 OS = syst3m.defaults.operating_system(supported=["macos", "linux"])
 syst3m.defaults.alias(alias=ALIAS, executable=f"{SOURCE_PATH}")
 
+# version.
+version = Files.load(f"{SOURCE_PATH}/.version")
+
 # universal variables.
 OWNER = os.environ.get("USER")
 GROUP = "root"
